# remirepo spec file for php-pecl-eio
#
# Copyright (c) 2013-2024 Remi Collet
# License: CC-BY-SA-4.0
# http://creativecommons.org/licenses/by-sa/4.0/
#
# Please, preserve the changelog entries
#
%{?scl:%scl_package php-pecl-eio}

# For PHP < 5.6 and EPEL-9
%{!?__phpize:      %global __phpize       %{_bindir}/phpize}
%{!?__ztsphpize:   %global __ztsphpize    %{_bindir}/zts-phpize}
%{!?__phpconfig:   %global __phpconfig    %{_bindir}/php-config}
%{!?__ztsphpconfig:%global __ztsphpconfig %{_bindir}/zts-php-config}

%bcond_without    tests

%global pecl_name eio
%global with_zts  0%{!?_without_zts:%{?__ztsphp:1}}
%if "%{php_version}" < "5.6"
# After sockets
%global ini_name  z-%{pecl_name}.ini
%else
# After 20-sockets
%global ini_name  40-%{pecl_name}.ini
%endif

%global upstream_version 3.1.0
#global upstream_prever  RC1
%global sources          %{pecl_name}-%{upstream_version}%{?upstream_prever}
%global _configure       ../%{sources}/configure

#
# NOTE: bundled libeio (which is retired from Fedora)
#

Summary:        Provides interface to the libeio library
Name:           %{?scl_prefix}php-pecl-%{pecl_name}
Version:        %{upstream_version}%{?upstream_prever:~%{upstream_prever}}
Release:        2%{?dist}%{!?scl:%{!?nophptag:%(%{__php} -r 'echo ".".PHP_MAJOR_VERSION.".".PHP_MINOR_VERSION;')}}
# Extension is PHP-3.01, library is BSD-2-Clause (or GPL-2.0-or-later)
License:        PHP-3.01 AND BSD-2-Clause
URL:            https://pecl.php.net/package/%{pecl_name}
Source0:        https://pecl.php.net/get/%{pecl_name}-%{upstream_version}%{?upstream_prever}.tgz

BuildRequires:  make
BuildRequires:  %{?dtsprefix}gcc
BuildRequires:  %{?scl_prefix}php-devel
BuildRequires:  %{?scl_prefix}php-pear
BuildRequires:  %{?scl_prefix}php-sockets
# For tests
BuildRequires:  %{?scl_prefix}php-posix

Requires:       %{?scl_prefix}php(zend-abi) = %{php_zend_api}
Requires:       %{?scl_prefix}php(api) = %{php_core_api}
Requires:       %{?scl_prefix}php-sockets%{?_isa}

Provides:       %{?scl_prefix}php-%{pecl_name} = %{version}
Provides:       %{?scl_prefix}php-%{pecl_name}%{?_isa} = %{version}
Provides:       %{?scl_prefix}php-pecl(%{pecl_name}) = %{version}
Provides:       %{?scl_prefix}php-pecl(%{pecl_name})%{?_isa} = %{version}

Provides:       bundled(libeio)


%description
This extension provides interface to the libeio library written by Marc Lehmann
(see http://software.schmorp.de/pkg/libeio.html).

Libeio is a an asynchronous I/O library. Features basically include
asynchronous versions of POSIX API(read, write, open, close, stat, unlink,
fdatasync, mknod, readdir etc.); sendfile (native on Solaris, Linux, HP-UX,
FreeBSD); readahead. libeio itself emulates the system calls, if they are not
available on specific(UNIX-like) platform.

Package built for PHP %(%{__php} -r 'echo PHP_MAJOR_VERSION.".".PHP_MINOR_VERSION;')%{?scl: as Software Collection (%{scl} by %{?scl_vendor}%{!?scl_vendor:rh})}.


%prep
%setup -q -c
# Don't install/register tests
sed -e 's/role="test"/role="src"/' \
    %{?_licensedir:-e '/LICENSE/s/role="doc"/role="src"/' } \
    -i package.xml

cd %{sources}
# Sanity check, really often broken
extver=$(sed -n '/define PHP_EIO_VERSION/{s/.* "//;s/".*$//;p}' php%(%{__php} -r 'echo PHP_MAJOR_VERSION;')/php_eio.h)
if test "x${extver}" != "x%{upstream_version}%{?upstream_prever}"; then
   : Error: Upstream version is ${extver}, expecting %{upstream_version}%{?upstream_prever}.
   exit 1
fi
cd ..

mkdir NTS
%if %{with_zts}
mkdir ZTS
%endif

# Create configuration file
cat << 'EOF' | tee %{ini_name}
; Enable %{pecl_name} extension module
extension=%{pecl_name}.so
EOF


%build
%{?dtsenable}

cd %{sources}
%{__phpize}

cd ../NTS
%configure \
    --with-libdir=%{_lib} \
    --with-php-config=%{__phpconfig}

make %{?_smp_mflags}

%if %{with_zts}
cd ../ZTS
%configure \
    --with-libdir=%{_lib} \
    --with-php-config=%{__ztsphpconfig}

make %{?_smp_mflags}
%endif


%install
%{?dtsenable}

make -C NTS install INSTALL_ROOT=%{buildroot}

# install config file
install -D -m 644 %{ini_name} %{buildroot}%{php_inidir}/%{ini_name}

# Install XML package description
install -D -m 644 package.xml %{buildroot}%{pecl_xmldir}/%{name}.xml

%if %{with_zts}
make -C ZTS install INSTALL_ROOT=%{buildroot}

install -D -m 644 %{ini_name} %{buildroot}%{php_ztsinidir}/%{ini_name}
%endif

# Documentation
cd %{sources}
for i in $(grep 'role="doc"' ../package.xml | sed -e 's/^.*name="//;s/".*$//')
do install -Dpm 644 $i %{buildroot}%{pecl_docdir}/%{pecl_name}/$i
done


%if 0%{?fedora} < 24 && 0%{?rhel} < 8
# when pear installed alone, after us
%triggerin -- %{?scl_prefix}php-pear
if [ -x %{__pecl} ] ; then
    %{pecl_install} %{pecl_xmldir}/%{name}.xml >/dev/null || :
fi

# posttrans as pear can be installed after us
%posttrans
if [ -x %{__pecl} ] ; then
    %{pecl_install} %{pecl_xmldir}/%{name}.xml >/dev/null || :
fi

%postun
if [ $1 -eq 0 -a -x %{__pecl} ] ; then
    %{pecl_uninstall} %{pecl_name} >/dev/null || :
fi
%endif


%check
DEPMOD=
[ -f %{php_extdir}/sockets.so ] && DEPMOD="$DEPMOD -d extension=sockets.so"
[ -f %{php_extdir}/posix.so ]   && DEPMOD="$DEPMOD -d extension=posix.so"

: Minimal load test for NTS extension
cd %{sources}
%{__php} --no-php-ini \
    $DEPMOD \
    --define extension=%{buildroot}%{php_extdir}/%{pecl_name}.so \
    --modules | grep '^%{pecl_name}$'

%if %{with tests}
# see https://github.com/rosmanov/pecl-eio/issues/21
rm tests/eio_fallocate_basic.phpt

: Upstream test suite for NTS extension
TEST_PHP_EXECUTABLE=%{__php} \
TEST_PHP_ARGS="-n $DEPMOD -d extension=%{buildroot}%{php_extdir}/%{pecl_name}.so" \
REPORT_EXIT_STATUS=1 \
%{__php} -n run-tests.php -q --show-diff
%endif

%if %{with_zts}
: Minimal load test for ZTS extension
%{__ztsphp} --no-php-ini \
    $DEPMOD \
    --define extension=%{buildroot}%{php_ztsextdir}/%{pecl_name}.so \
    --modules | grep '^%{pecl_name}$'

%if %{with tests}
: Upstream test suite for ZTS extension
TEST_PHP_EXECUTABLE=%{__ztsphp} \
TEST_PHP_ARGS="-n $DEPMOD -d extension=%{buildroot}%{php_ztsextdir}/%{pecl_name}.so" \
REPORT_EXIT_STATUS=1 \
%{__ztsphp} -n run-tests.php -q --show-diff
%endif
%endif


%files
%{?_licensedir:%license %{sources}/LICENSE}
%doc %{pecl_docdir}/%{pecl_name}
%{pecl_xmldir}/%{name}.xml

%config(noreplace) %{php_inidir}/%{ini_name}
%{php_extdir}/%{pecl_name}.so

%if %{with_zts}
%config(noreplace) %{php_ztsinidir}/%{ini_name}
%{php_ztsextdir}/%{pecl_name}.so
%endif


%changelog
* Mon Feb 26 2024 Remi Collet <remi@remirepo.net> - 3.1.0-2
- F40: ignore 1 test failing reported as
  https://github.com/rosmanov/pecl-eio/issues/21

* Mon Sep 11 2023 Remi Collet <remi@remirepo.net> - 3.1.0-1
- update to 3.1.0

* Tue Sep  5 2023 Remi Collet <remi@remirepo.net> - 3.1.0~RC1-2
- add patch for PHP from discussion on
  https://github.com/rosmanov/pecl-eio/issues/19

* Thu Jun  1 2023 Remi Collet <remi@remirepo.net> - 3.1.0~RC1-1
- update to 3.1.0RC1
- build out of sources tree

* Tue Sep 21 2021 Remi Collet <remi@remirepo.net> - 3.0.0~RC4-1
- update to 3.0.0RC4 (no change)
- drop patch merged upstream

* Tue Sep 21 2021 Remi Collet <remi@remirepo.net> - 3.0.0~RC3-1
- update to 3.0.0RC3
- open https://github.com/rosmanov/pecl-eio/pull/14 deprecated calls

* Thu Sep  9 2021 Remi Collet <remi@remirepo.net> - 3.0.0~RC2-2
- ignore 4 tests for 8.1 (deprecated calls)

* Mon Apr 19 2021 Remi Collet <remi@remirepo.net> - 3.0.0~RC2-1
- update to 3.0.0RC2

* Tue Sep 03 2019 Remi Collet <remi@remirepo.net> - 2.0.4-5
- rebuild for 7.4.0RC1

* Tue Jul 23 2019 Remi Collet <remi@remirepo.net> - 2.0.4-4
- fix configuration file name in SCL

* Tue Jul 23 2019 Remi Collet <remi@remirepo.net> - 2.0.4-3
- rebuild for 7.4.0beta1

* Thu Aug 16 2018 Remi Collet <remi@remirepo.net> - 2.0.4-2
- rebuild for 7.3.0beta2 new ABI

* Thu Aug  9 2018 Remi Collet <remi@remirepo.net> - 2.0.4-1
- update to 2.0.4

* Wed Jul 18 2018 Remi Collet <remi@remirepo.net> - 2.0.3-2
- rebuld for 7.3.0alpha4 new ABI

* Tue Jun 26 2018 Remi Collet <remi@remirepo.net> - 2.0.3-1
- update to 2.0.3
- drop patch merged upstream

* Tue Jun 26 2018 Remi Collet <remi@remirepo.net> - 2.0.2-4
- add patch for PHP 7.3 from
  https://github.com/rosmanov/pecl-eio/pull/8

* Tue Jul 18 2017 Remi Collet <remi@remirepo.net> - 2.0.2-3
- rebuild for PHP 7.2.0beta1 new API

* Wed Jun 21 2017 Remi Collet <remi@remirepo.net> - 2.0.2-2
- rebuild for 7.2.0alpha2

* Fri Apr 21 2017 Remi Collet <remi@remirepo.net> - 2.0.2-1
- Update to 2.0.2

* Thu Dec  1 2016 Remi Collet <remi@fedoraproject.org> - 2.0.1-3
- rebuild with PHP 7.1.0 GA

* Wed Sep 14 2016 Remi Collet <remi@fedoraproject.org> - 2.0.1-2
- rebuild for PHP 7.1 new API version

* Mon Jul 25 2016 Remi Collet <remi@fedoraproject.org> - 2.0.1-1
- Update to 2.0.1

* Wed Jun  8 2016 Remi Collet <remi@fedoraproject.org> - 2.0.0-1
- Update to 2.0.0 (stable)

* Wed Mar 23 2016 Remi Collet <remi@fedoraproject.org> - 2.0.0-0.4.RC3
- Update to 2.0.0RC3 (no change)

* Fri Mar  4 2016 Remi Collet <remi@fedoraproject.org> - 2.0.0-0.3.RC2
- Update to 2.0.0RC2

* Fri Nov 20 2015 Remi Collet <remi@fedoraproject.org> - 2.0.0-0.2.RC1
- fix PHP 7 and ZTS build
  open https://bitbucket.org/osmanov/pecl-eio/issues/3
  open https://bitbucket.org/osmanov/pecl-eio/pull-requests/4

* Thu Nov 19 2015 Remi Collet <remi@fedoraproject.org> - 2.0.0-0.1.RC1
- Update to 2.0.0RC1

* Mon Sep 28 2015 Remi Collet <remi@fedoraproject.org> - 1.2.6-1
- Update to 1.2.6
- don't install/register tests
- allow build against rh-php56 (as more-php56)
- drop runtime dependency on pear, new scriptlets

* Wed Dec 24 2014 Remi Collet <remi@fedoraproject.org> - 1.2.5-3.1
- Fedora 21 SCL mass rebuild

* Tue Aug 26 2014 Remi Collet <rcollet@redhat.com> - 1.2.5-3
- improve SCL build

* Wed Apr  9 2014 Remi Collet <remi@fedoraproject.org> - 1.2.5-2
- add numerical prefix to extension configuration file

* Thu Mar 27 2014 Remi Collet <remi@fedoraproject.org> - 1.2.5-1
- Update to 1.2.5 (stable)

* Sun Mar 23 2014 Remi Collet <remi@fedoraproject.org> - 1.2.4-2
- allow SCL build

* Sat Mar 15 2014 Remi Collet <remi@fedoraproject.org> - 1.2.4-1
- Update to 1.2.4 (stable)
- install doc in pecl_docdir
- install tests in pecl_testdir

* Tue Oct  8 2013 Remi Collet <remi@fedoraproject.org> - 1.2.3-1
- initial package
